@@ -26,7 +26,7 @@
 extern "C" {
 #endif
 
-#define LIBGNUTLS_VERSION "0.5.3"
+#define LIBGNUTLS_VERSION "0.5.4"
 
 #include <sys/types.h>
 #include <time.h>
@@ -34,10 +34,18 @@ extern "C" {
 #define GNUTLS_CIPHER_AES_128_CBC GNUTLS_CIPHER_RIJNDAEL_128_CBC
 #define GNUTLS_CIPHER_AES_256_CBC GNUTLS_CIPHER_RIJNDAEL_256_CBC
 #define GNUTLS_CIPHER_RIJNDAEL_CBC GNUTLS_CIPHER_RIJNDAEL_128_CBC
+#define GNUTLS_CIPHER_ARCFOUR GNUTLS_CIPHER_ARCFOUR_128
 
-typedef enum GNUTLS_BulkCipherAlgorithm { GNUTLS_CIPHER_NULL=1, GNUTLS_CIPHER_ARCFOUR, GNUTLS_CIPHER_3DES_CBC, GNUTLS_CIPHER_RIJNDAEL_128_CBC, GNUTLS_CIPHER_TWOFISH_128_CBC, GNUTLS_CIPHER_RIJNDAEL_256_CBC } GNUTLS_BulkCipherAlgorithm;
+typedef enum GNUTLS_BulkCipherAlgorithm { GNUTLS_CIPHER_NULL=1, 
+	GNUTLS_CIPHER_ARCFOUR_128, GNUTLS_CIPHER_3DES_CBC, GNUTLS_CIPHER_RIJNDAEL_128_CBC, 
+	GNUTLS_CIPHER_TWOFISH_128_CBC, GNUTLS_CIPHER_RIJNDAEL_256_CBC,
+	GNUTLS_CIPHER_ARCFOUR_40
+} GNUTLS_BulkCipherAlgorithm;
 
-typedef enum GNUTLS_KXAlgorithm { GNUTLS_KX_RSA=1, GNUTLS_KX_DHE_DSS, GNUTLS_KX_DHE_RSA, GNUTLS_KX_ANON_DH, GNUTLS_KX_SRP } GNUTLS_KXAlgorithm;
+typedef enum GNUTLS_KXAlgorithm { GNUTLS_KX_RSA=1, GNUTLS_KX_DHE_DSS, 
+	GNUTLS_KX_DHE_RSA, GNUTLS_KX_ANON_DH, GNUTLS_KX_SRP,
+	GNUTLS_KX_RSA_EXPORT
+} GNUTLS_KXAlgorithm;
 
 typedef enum GNUTLS_CredType { GNUTLS_CRD_CERTIFICATE=1, GNUTLS_CRD_ANON, GNUTLS_CRD_SRP } GNUTLS_CredType;
 
@@ -105,6 +113,9 @@ typedef struct GNUTLS_STATE_INT* GNUTLS_STATE;
 struct GNUTLS_DH_PARAMS_INT;
 typedef struct GNUTLS_DH_PARAMS_INT* GNUTLS_DH_PARAMS;
 
+struct GNUTLS_RSA_PARAMS_INT;
+typedef struct GNUTLS_RSA_PARAMS_INT* GNUTLS_RSA_PARAMS;
+
 typedef struct {
 	unsigned char * data;
 	int size;
@@ -154,7 +165,6 @@ const char* gnutls_strerror( int error);
  */
 void gnutls_handshake_set_private_extensions(GNUTLS_STATE state, int allow);
 void gnutls_record_set_cbc_protection(GNUTLS_STATE state, int prot);
-void gnutls_handshake_set_exportable_detection(GNUTLS_STATE state, int det);
 void gnutls_handshake_set_rsa_pms_check(GNUTLS_STATE state, int check);
 
 /* Record layer functions.
@@ -261,6 +271,7 @@ int gnutls_certificate_allocate_cred( GNUTLS_CERTIFICATE_CREDENTIALS *sc);
 #define gnutls_certificate_allocate_sc gnutls_certificate_allocate_cred
 
 int gnutls_certificate_set_dh_params(GNUTLS_CERTIFICATE_CREDENTIALS res, GNUTLS_DH_PARAMS);
+int gnutls_certificate_set_rsa_params(GNUTLS_CERTIFICATE_CREDENTIALS res, GNUTLS_RSA_PARAMS rsa_params);
 
 int gnutls_certificate_set_x509_trust_file( GNUTLS_CERTIFICATE_CREDENTIALS res, const char* CAFILE, 
 	GNUTLS_X509_CertificateFmt);
@@ -292,11 +303,24 @@ typedef void (*GNUTLS_LOG_FUNC)( const char*);
 void gnutls_global_set_log_function( GNUTLS_LOG_FUNC log_func);
 #define gnutls_global_set_log_func gnutls_global_set_log_function
 
+/* DH params */
 int gnutls_dh_params_set( GNUTLS_DH_PARAMS, gnutls_datum prime, gnutls_datum generator, int bits);
 int gnutls_dh_params_init( GNUTLS_DH_PARAMS*);
 void gnutls_dh_params_deinit( GNUTLS_DH_PARAMS);
 int gnutls_dh_params_generate( gnutls_datum* prime, gnutls_datum* generator, int bits);
 
+/* RSA params */
+int gnutls_rsa_params_set(GNUTLS_RSA_PARAMS rsa_params, 
+	gnutls_datum m, gnutls_datum e, gnutls_datum d, 
+	gnutls_datum p, gnutls_datum q, gnutls_datum u,
+	int bits);
+int gnutls_rsa_params_generate(gnutls_datum * m, gnutls_datum *e,
+	gnutls_datum *d, gnutls_datum *p, gnutls_datum* q, 
+	gnutls_datum* u, int bits);
+int gnutls_rsa_params_init(GNUTLS_RSA_PARAMS * rsa_params);
+void gnutls_rsa_params_deinit(GNUTLS_RSA_PARAMS rsa_params);
+
+
 typedef ssize_t (*GNUTLS_PULL_FUNC)(GNUTLS_TRANSPORT_PTR, void*, size_t);
 typedef ssize_t (*GNUTLS_PUSH_FUNC)(GNUTLS_TRANSPORT_PTR, const void*, size_t);
 void gnutls_transport_set_ptr(GNUTLS_STATE state, GNUTLS_TRANSPORT_PTR ptr);
@@ -392,6 +416,9 @@ int gnutls_dh_get_prime_bits( GNUTLS_STATE);
 int gnutls_dh_get_secret_bits( GNUTLS_STATE);
 int gnutls_dh_get_peers_public_bits( GNUTLS_STATE);
 
+/* RSA */
+int gnutls_rsa_export_get_modulus_bits(GNUTLS_STATE state);
+
 /* X509PKI */
 
 void gnutls_certificate_client_set_select_function( GNUTLS_STATE, gnutls_certificate_client_select_function *);
@@ -525,6 +552,7 @@ int gnutls_b64_decode_fmt2( const gnutls_datum *b64_data, const gnutls_datum* re
 #define GNUTLS_E_INIT_LIBEXTRA -82
 #define GNUTLS_E_LIBRARY_VERSION_MISMATCH -82
 #define GNUTLS_E_EXPORT_CIPHER_SUITE -83
+#define GNUTLS_E_NO_TEMPORARY_RSA_PARAMS -84
 
 #define GNUTLS_E_UNIMPLEMENTED_FEATURE -250
 
