@@ -16,7 +16,12 @@
  *  You should have received a copy of the GNU Lesser General Public
  *  License along with this library; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
- * */
+ * 
+ */
+
+/* The certificate authentication functions which are needed in the handshake,
+ * and are common to RSA and DHE key exchange, are in this file.
+ */
 
 #include <gnutls_int.h>
 #include "gnutls_auth_int.h"
@@ -603,7 +608,7 @@ int _gnutls_gen_openpgp_certificate_fpr(GNUTLS_STATE state,
 
 	if (_E_gnutls_openpgp_fingerprint==NULL) {
 		gnutls_assert();
-		return GNUTLS_E_INVALID_REQUEST;
+		return GNUTLS_E_INIT_LIBEXTRA;
 	}
 
 	if ( (ret=_E_gnutls_openpgp_fingerprint( &apr_cert_list[0].raw, pdata, &fpr_size)) < 0) {
@@ -856,7 +861,7 @@ int _gnutls_proc_openpgp_server_certificate(GNUTLS_STATE state,
 		 */
 		if (_E_gnutls_openpgp_request_key==NULL) {
 			gnutls_assert();
-			return GNUTLS_E_INVALID_REQUEST;
+			return GNUTLS_E_INIT_LIBEXTRA;
 		}
 		if ( (ret=_E_gnutls_openpgp_request_key( &akey, cred, p, 20)) < 0) {
 			gnutls_assert();
@@ -915,7 +920,7 @@ int _gnutls_proc_openpgp_server_certificate(GNUTLS_STATE state,
 		gnutls_free_datum( &akey);
 		CLEAR_CERTS;
 		gnutls_afree(peer_certificate_list);
-		return GNUTLS_E_INVALID_REQUEST;
+		return GNUTLS_E_INIT_LIBEXTRA;
 	}
 	
 	if ((ret =
@@ -1158,7 +1163,7 @@ int _gnutls_proc_cert_client_cert_vrfy(GNUTLS_STATE state, opaque * data,
 	case GNUTLS_CRT_OPENPGP:
 		if (_E_gnutls_openpgp_cert2gnutls_cert==NULL) {
 			gnutls_assert();
-			return GNUTLS_E_INVALID_REQUEST;
+			return GNUTLS_E_INIT_LIBEXTRA;
 		}
 		ret =
 		    _E_gnutls_openpgp_cert2gnutls_cert(&peer_cert,
