@@ -34,6 +34,7 @@ typedef struct {
 static const gnutls_cred_map cred_mappings[] = {
 	{ GNUTLS_KX_ANON_DH, GNUTLS_CRD_ANON    },
 	{ GNUTLS_KX_RSA,     GNUTLS_CRD_CERTIFICATE },
+	{ GNUTLS_KX_RSA_EXPORT,     GNUTLS_CRD_CERTIFICATE },
 	{ GNUTLS_KX_DHE_DSS, GNUTLS_CRD_CERTIFICATE },
 	{ GNUTLS_KX_DHE_RSA, GNUTLS_CRD_CERTIFICATE },
 	{ GNUTLS_KX_SRP,     GNUTLS_CRD_SRP     },
@@ -80,6 +81,7 @@ struct gnutls_cipher_entry {
 	size_t keysize;
 	CipherType block;
 	size_t iv;
+	int export_flag; /* 0 non export */
 };
 typedef struct gnutls_cipher_entry gnutls_cipher_entry;
 
@@ -89,12 +91,13 @@ typedef struct gnutls_cipher_entry gnutls_cipher_entry;
  * protecting communications" by Hugo Krawczyk - CRYPTO 2001
  */
 static const gnutls_cipher_entry algorithms[] = {
-	{"3DES 168 CBC", GNUTLS_CIPHER_3DES_CBC, 8, 24, CIPHER_BLOCK, 8 },
-	{"RIJNDAEL 128 CBC", GNUTLS_CIPHER_RIJNDAEL_128_CBC, 16, 16, CIPHER_BLOCK, 16 },
-	{"RIJNDAEL 256 CBC", GNUTLS_CIPHER_RIJNDAEL_256_CBC, 16, 32, CIPHER_BLOCK, 16 },
-	{"TWOFISH 128 CBC", GNUTLS_CIPHER_TWOFISH_128_CBC, 16, 16, CIPHER_BLOCK, 16 },
-	{"ARCFOUR 128", GNUTLS_CIPHER_ARCFOUR, 1, 16, CIPHER_STREAM, 0 },
-	{"NULL", GNUTLS_CIPHER_NULL, 1, 0, CIPHER_STREAM, 0 },
+	{"3DES 168 CBC", GNUTLS_CIPHER_3DES_CBC, 8, 24, CIPHER_BLOCK, 8, 0 },
+	{"RIJNDAEL 128 CBC", GNUTLS_CIPHER_RIJNDAEL_128_CBC, 16, 16, CIPHER_BLOCK, 16, 0 },
+	{"RIJNDAEL 256 CBC", GNUTLS_CIPHER_RIJNDAEL_256_CBC, 16, 32, CIPHER_BLOCK, 16, 0 },
+	{"TWOFISH 128 CBC", GNUTLS_CIPHER_TWOFISH_128_CBC, 16, 16, CIPHER_BLOCK, 16, 0 },
+	{"ARCFOUR 128", GNUTLS_CIPHER_ARCFOUR_128, 1, 16, CIPHER_STREAM, 0, 0 },
+	{"ARCFOUR 40", GNUTLS_CIPHER_ARCFOUR_40, 1, 5, CIPHER_STREAM, 0, 1 },
+	{"NULL", GNUTLS_CIPHER_NULL, 1, 0, CIPHER_STREAM, 0, 0 },
 	{0}
 };
 
@@ -160,6 +163,7 @@ static const gnutls_compression_entry compression_algorithms[] = {
 
 
 extern MOD_AUTH_STRUCT rsa_auth_struct;
+extern MOD_AUTH_STRUCT rsa_export_auth_struct;
 extern MOD_AUTH_STRUCT dhe_rsa_auth_struct;
 extern MOD_AUTH_STRUCT dhe_dss_auth_struct;
 extern MOD_AUTH_STRUCT anon_auth_struct;
@@ -173,6 +177,7 @@ gnutls_kx_algo_entry _gnutls_kx_algorithms[MAX_KX_ALGOS] = {
 	{ "Anon DH", GNUTLS_KX_ANON_DH, &anon_auth_struct },
 #endif
 	{ "RSA", GNUTLS_KX_RSA, &rsa_auth_struct },
+	{ "RSA EXPORT", GNUTLS_KX_RSA_EXPORT, &rsa_export_auth_struct },
 	{ "DHE RSA", GNUTLS_KX_DHE_RSA, &dhe_rsa_auth_struct },
 	{ "DHE DSS", GNUTLS_KX_DHE_DSS, &dhe_dss_auth_struct },
 	{0}
@@ -241,6 +246,8 @@ typedef struct {
 #define GNUTLS_RSA_ARCFOUR_MD5 { 0x00, 0x04 }
 #define GNUTLS_RSA_3DES_EDE_CBC_SHA { 0x00, 0x0A }
 
+#define GNUTLS_RSA_EXPORT_ARCFOUR_40_MD5 { 0x00, 0x03 }
+
 /* draft-ietf-tls-ciphersuite-05: 
  */
 #define GNUTLS_RSA_RIJNDAEL_128_CBC_SHA { 0x00, 0x2F }
@@ -288,7 +295,7 @@ typedef struct {
 static const gnutls_cipher_suite_entry cs_algorithms[] = {
 	/* ANON_DH */
 	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_ANON_DH_ARCFOUR_MD5,
-				  GNUTLS_CIPHER_ARCFOUR,
+				  GNUTLS_CIPHER_ARCFOUR_128,
 				  GNUTLS_KX_ANON_DH, GNUTLS_MAC_MD5, GNUTLS_SSL3),
 	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_ANON_DH_3DES_EDE_CBC_SHA,
 				  GNUTLS_CIPHER_3DES_CBC, GNUTLS_KX_ANON_DH,
@@ -305,10 +312,10 @@ static const gnutls_cipher_suite_entry cs_algorithms[] = {
 
 	/* SRP */
 	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_SRP_ARCFOUR_SHA,
-				  GNUTLS_CIPHER_ARCFOUR,
+				  GNUTLS_CIPHER_ARCFOUR_128,
 				  GNUTLS_KX_SRP, GNUTLS_MAC_SHA, GNUTLS_TLS1),
 	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_SRP_ARCFOUR_MD5,
-				  GNUTLS_CIPHER_ARCFOUR,
+				  GNUTLS_CIPHER_ARCFOUR_128,
 				  GNUTLS_KX_SRP, GNUTLS_MAC_MD5, GNUTLS_TLS1),
 	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_SRP_3DES_EDE_CBC_SHA,
 				  GNUTLS_CIPHER_3DES_CBC, GNUTLS_KX_SRP,
@@ -325,7 +332,7 @@ static const gnutls_cipher_suite_entry cs_algorithms[] = {
 
 	/* DHE_DSS */
 	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_DHE_DSS_ARCFOUR_SHA,
-				  GNUTLS_CIPHER_ARCFOUR, GNUTLS_KX_DHE_DSS,
+				  GNUTLS_CIPHER_ARCFOUR_128, GNUTLS_KX_DHE_DSS,
 				  GNUTLS_MAC_SHA, GNUTLS_TLS1),
 	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_DHE_DSS_TWOFISH_128_CBC_SHA,
 				  GNUTLS_CIPHER_TWOFISH_128_CBC, GNUTLS_KX_DHE_DSS,
@@ -359,11 +366,15 @@ static const gnutls_cipher_suite_entry cs_algorithms[] = {
 				  GNUTLS_CIPHER_NULL,
 				  GNUTLS_KX_RSA, GNUTLS_MAC_MD5, GNUTLS_SSL3),
 
+	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_RSA_EXPORT_ARCFOUR_40_MD5,
+				  GNUTLS_CIPHER_ARCFOUR_40,
+				  GNUTLS_KX_RSA_EXPORT, GNUTLS_MAC_MD5, GNUTLS_SSL3),
+
 	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_RSA_ARCFOUR_SHA,
-				  GNUTLS_CIPHER_ARCFOUR,
+				  GNUTLS_CIPHER_ARCFOUR_128,
 				  GNUTLS_KX_RSA, GNUTLS_MAC_SHA, GNUTLS_SSL3),
 	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_RSA_ARCFOUR_MD5,
-				  GNUTLS_CIPHER_ARCFOUR,
+				  GNUTLS_CIPHER_ARCFOUR_128,
 				  GNUTLS_KX_RSA, GNUTLS_MAC_MD5, GNUTLS_SSL3),
 	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_RSA_3DES_EDE_CBC_SHA,
 				  GNUTLS_CIPHER_3DES_CBC,
@@ -579,6 +590,14 @@ int _gnutls_cipher_get_iv_size(BulkCipherAlgorithm algorithm)
 
 }
 
+int _gnutls_cipher_get_export_flag(BulkCipherAlgorithm algorithm)
+{				/* In bytes */
+	size_t ret = 0;
+	GNUTLS_ALG_LOOP(ret = p->export_flag);
+	return ret;
+
+}
+
 /**
   * gnutls_cipher_get_name - Returns a string with the name of the specified cipher algorithm
   * @algorithm: is an encryption algorithm
