@@ -2,7 +2,7 @@
 # define GNUTLS_CERT_H
 
 #include <gnutls_pk.h>
-#include <x509_asn1.h>
+#include <libtasn1.h>
 #include <gnutls_ui.h>
 
 #define MAX_PARAMS_SIZE 6 /* ok for RSA and DSA */
@@ -47,9 +47,6 @@ typedef struct gnutls_cert {
  	uint16	   keyUsage; /* bits from X509KEY_* 
  	                      */
  	
-	int        valid; /* 0 if the certificate looks good.
-	                   */
-
 	int        CA;    /* 0 if the certificate does not belong to
 	                   * a certificate authority. 1 otherwise.
 	                   */
