@@ -1,10 +1,10 @@
 #ifndef GNUTLS_GLOBAL_H
 # define GNUTLS_GLOBAL_H
 
-#include <x509_asn1.h>
+#include <libtasn1.h>
 
 int gnutls_is_secure_memory(const void* mem);
-node_asn* _gnutls_get_gnutls_asn(void);
-node_asn* _gnutls_get_pkix(void);
+ASN1_TYPE _gnutls_get_gnutls_asn(void);
+ASN1_TYPE _gnutls_get_pkix(void);
 
 #endif
