@@ -155,8 +155,9 @@ typedef enum ConnectionEnd { GNUTLS_SERVER=1, GNUTLS_CLIENT
 #define GNUTLS_ConnectionEnd ConnectionEnd
 
 typedef enum BulkCipherAlgorithm { GNUTLS_CIPHER_NULL=1, 
-	GNUTLS_CIPHER_ARCFOUR, GNUTLS_CIPHER_3DES_CBC, GNUTLS_CIPHER_RIJNDAEL_128_CBC, 
-	GNUTLS_CIPHER_TWOFISH_128_CBC, GNUTLS_CIPHER_RIJNDAEL_256_CBC 
+	GNUTLS_CIPHER_ARCFOUR_128, GNUTLS_CIPHER_3DES_CBC, GNUTLS_CIPHER_RIJNDAEL_128_CBC, 
+	GNUTLS_CIPHER_TWOFISH_128_CBC, GNUTLS_CIPHER_RIJNDAEL_256_CBC,
+	GNUTLS_CIPHER_ARCFOUR_40
 } BulkCipherAlgorithm;
 #define GNUTLS_BulkCipherAlgorithm BulkCipherAlgorithm
 	
@@ -164,7 +165,8 @@ typedef enum Extensions { GNUTLS_EXTENSION_MAX_RECORD_SIZE=1, GNUTLS_EXTENSION_S
 } Extensions;
 
 typedef enum KXAlgorithm { GNUTLS_KX_RSA=1, GNUTLS_KX_DHE_DSS, 
-	GNUTLS_KX_DHE_RSA, GNUTLS_KX_ANON_DH, GNUTLS_KX_SRP 
+	GNUTLS_KX_DHE_RSA, GNUTLS_KX_ANON_DH, GNUTLS_KX_SRP,
+	GNUTLS_KX_RSA_EXPORT
 } KXAlgorithm;
 #define GNUTLS_KXAlgorithm KXAlgorithm
 
@@ -246,9 +248,9 @@ struct GNUTLS_KEY_INT {
 	MPI				b;
 	MPI				a;
 	MPI				x;
-
-	/* RSA: does not use these.
+	/* RSA: e, m
 	 */
+	MPI 				rsa[2];
 	
 	/* this is used to hold the peers authentication data 
 	 */
@@ -315,6 +317,11 @@ typedef struct {
 /* if you add anything in Security_Parameters struct, then
  * also modify CPY_COMMON in gnutls_constate.c
  */
+
+/* Note that the security parameters structure is set up after the
+ * handshake has finished. The only value you may depend on while
+ * the handshake is in progress is the cipher suite value.
+ */
 typedef struct {
 	ConnectionEnd entity;
 	KXAlgorithm kx_algorithm;
@@ -561,7 +568,6 @@ typedef struct {
 	GNUTLS_Version		default_record_version;
 
 	int			cbc_protection_hack;
-	int			exportable_detection_hack;
 
 	int			rsa_pms_check; /* 0 means enabled */
 
@@ -604,6 +610,15 @@ typedef struct {
 
 #define GNUTLS_DH_PARAMS _GNUTLS_DH_PARAMS*
 
+
+typedef struct {
+	int bits;
+	MPI params[RSA_PRIVATE_PARAMS];
+} _GNUTLS_RSA_PARAMS;
+
+#define GNUTLS_RSA_PARAMS _GNUTLS_RSA_PARAMS*
+
+
 /* functions */
 void _gnutls_set_current_version(GNUTLS_STATE state, GNUTLS_Version version);
 GNUTLS_Version gnutls_protocol_get_version(GNUTLS_STATE state);
