@@ -5,9 +5,12 @@
  */
 #define GNUTLS_BACKWARDS_COMPATIBLE 
 
-
 #ifdef GNUTLS_BACKWARDS_COMPATIBLE
 
+void gnutls_handshake_set_exportable_detection(GNUTLS_STATE state, int det)
+{
+	return;
+}
 
 /* nothing here */
 
