@@ -37,6 +37,7 @@
 #include <gnutls_state.h>
 #include <auth_cert.h>
 #include <auth_anon.h>
+#include <gnutls_algorithms.h>
 
 #define CHECK_AUTH(auth, ret) if (gnutls_auth_get_type(state) != auth) { \
 	gnutls_assert(); \
@@ -132,6 +133,7 @@ void _gnutls_handshake_internal_state_clear( GNUTLS_STATE state) {
 		sizeof(HANDSHAKE_HEADER_BUFFER));
 	state->gnutls_internals.adv_version_minor = 0;
 	state->gnutls_internals.adv_version_minor = 0;
+	state->gnutls_internals.handshake_direction = 0;
 
 	state->gnutls_internals.resumable = RESUME_TRUE;
 
@@ -283,6 +285,10 @@ void _gnutls_deinit(GNUTLS_STATE state)
 		_gnutls_mpi_release(&state->gnutls_key->B);
 		_gnutls_mpi_release(&state->gnutls_key->b);
 
+		/* RSA */
+		_gnutls_mpi_release(&state->gnutls_key->rsa[0]);
+		_gnutls_mpi_release(&state->gnutls_key->rsa[1]);
+
 		_gnutls_mpi_release(&state->gnutls_key->dh_secret);
 		_gnutls_free(state->gnutls_key);
 
@@ -380,6 +386,19 @@ int _gnutls_dh_set_secret_bits( GNUTLS_STATE state, int bits) {
 	return 0;
 }
 
+int _gnutls_rsa_export_set_modulus_bits( GNUTLS_STATE state, int bits) {
+	CERTIFICATE_AUTH_INFO info;
+
+	info = _gnutls_get_auth_info(state);
+	if (info == NULL)
+		return GNUTLS_E_UNKNOWN_ERROR;
+
+	info->rsa_export_modulus_bits = bits;
+
+	return 0;
+}
+
+
 int _gnutls_dh_set_prime_bits( GNUTLS_STATE state, int bits) {
 	switch( gnutls_auth_get_type( state)) {
 		case GNUTLS_CRD_ANON: {
@@ -467,24 +486,6 @@ void gnutls_record_set_cbc_protection(GNUTLS_STATE state, int prot)
 	state->gnutls_internals.cbc_protection_hack = prot;
 }
 
-/**
-  * gnutls_handshake_set_exportable_detection - Used to enable the detection of server's export cipher suites
-  * @state: is a &GNUTLS_STATE structure.
-  * @det: is an integer (0 or 1)
-  *
-  * The function will allow clients to detect if a server only
-  * supports exportable ciphersuites. In that case an error code
-  * of GNUTLS_E_EXPORT_CIPHER_SUITE is returned.
-  *
-  * This check will be enabled if det != 0, and disabled otherwise
-  * (the default behaviour).
-  *
-  **/
-void gnutls_handshake_set_exportable_detection(GNUTLS_STATE state, int det)
-{
-	state->gnutls_internals.exportable_detection_hack = det;
-}
-
 /**
   * gnutls_handshake_set_private_extensions - Used to enable the private cipher suites
   * @state: is a &GNUTLS_STATE structure.
@@ -552,8 +553,9 @@ static int _gnutls_P_hash( MACAlgorithm algorithm, const opaque * secret, int se
 {
 
 	GNUTLS_MAC_HANDLE td2;
-	int i = 0, times, how, blocksize, A_size;
+	int i, times, how, blocksize, A_size;
 	opaque final[20], Atmp[MAX_SEED_SIZE];
+	int output_bytes;
 
 	if (seed_size > MAX_SEED_SIZE || total_bytes<=0) {
 		gnutls_assert();
@@ -561,16 +563,19 @@ static int _gnutls_P_hash( MACAlgorithm algorithm, const opaque * secret, int se
 	}
 	
 	blocksize = _gnutls_hmac_get_algo_len(algorithm);
+
+	output_bytes = 0;
 	do {
-		i += blocksize;
-	} while (i < total_bytes);
+		output_bytes += blocksize;
+	} while (output_bytes < total_bytes);
 
 	/* calculate A(0) */
 
 	memcpy( Atmp, seed, seed_size);
 	A_size = seed_size;
 
-	times = i / blocksize;
+	times = output_bytes / blocksize;
+
 	for (i = 0; i < times; i++) {
 		td2 = _gnutls_hmac_init(algorithm, secret, secret_size);
 
@@ -597,24 +602,14 @@ static int _gnutls_P_hash( MACAlgorithm algorithm, const opaque * secret, int se
 	return 0;
 }
 
-/* Function that xor's buffers using the maximum word size supported
- * by the system. It should be faster. - only if one / and % are much faster
- * than the whole xor operation.
+/* Xor's two buffers and puts the output in the first one.
  */
 inline static
-void _gnutls_xor(void* _o1, void* _o2, int _length) {
-unsigned long int* o1 = _o1;
-unsigned long int* o2 = _o2;
-int i, length = _length/sizeof(unsigned long int);
-int modlen = _length%sizeof(unsigned long int);
-
+void _gnutls_xor(opaque* o1, opaque* o2, int length) {
+int i;
 	for (i = 0; i < length; i++) {
 		o1[i] ^= o2[i];
 	}
-	i*=sizeof(unsigned long int);
-	for (;i<modlen;i++) {
-		((unsigned char*)_o1)[i] ^= ((unsigned char*)_o2)[i];
-	}
 	return ;
 }
 
@@ -700,6 +695,25 @@ int gnutls_session_is_resumed(GNUTLS_STATE state)
 	return 0;
 }
 
+/*-
+  * _gnutls_session_is_export - Used to check whether this session is of export grade
+  * @state: is a &GNUTLS_STATE structure.
+  *
+  * This function will return non zero if this session is of export grade.
+  *
+  -*/
+int _gnutls_session_is_export(GNUTLS_STATE state)
+{
+	BulkCipherAlgorithm cipher;
+	
+	cipher = _gnutls_cipher_suite_get_cipher_algo( state->security_parameters.current_cipher_suite);
+	
+	if (_gnutls_cipher_get_export_flag( cipher) != 0)
+		return 1;
+
+	return 0;
+}
+
 /**
   * gnutls_state_get_ptr - Used to get the user pointer from the state structure
   * @state: is a &GNUTLS_STATE structure.
