@@ -27,7 +27,10 @@ int _gnutls_dh_get_prime_bits( GNUTLS_STATE state);
 void gnutls_dh_set_prime_bits( GNUTLS_STATE state, int bits);
 void _gnutls_handshake_internal_state_clear( GNUTLS_STATE);
 
+int _gnutls_rsa_export_set_modulus_bits( GNUTLS_STATE state, int bits);
+
 int _gnutls_session_is_resumable( GNUTLS_STATE state);
+int _gnutls_session_is_export( GNUTLS_STATE state);
 
 int _gnutls_openpgp_send_fingerprint( GNUTLS_STATE state);
 
