@@ -74,11 +74,11 @@ int protocol_priority[16] = { GNUTLS_TLS1, GNUTLS_SSL3, 0 };
 int kx_priority[16] =
     { GNUTLS_KX_RSA, GNUTLS_KX_DHE_DSS, GNUTLS_KX_DHE_RSA, GNUTLS_KX_SRP,
   /* Do not use anonymous authentication, unless you know what that means */ 
-   GNUTLS_KX_ANON_DH, 0
+   GNUTLS_KX_ANON_DH, GNUTLS_KX_RSA_EXPORT, 0
 };
 int cipher_priority[16] =
-    { GNUTLS_CIPHER_RIJNDAEL_128_CBC, GNUTLS_CIPHER_3DES_CBC,
-   GNUTLS_CIPHER_ARCFOUR, 0
+    { GNUTLS_CIPHER_ARCFOUR_128, GNUTLS_CIPHER_RIJNDAEL_128_CBC, GNUTLS_CIPHER_3DES_CBC,
+   GNUTLS_CIPHER_ARCFOUR_40, 0
 };
 int comp_priority[16] = { GNUTLS_COMP_ZLIB, GNUTLS_COMP_NULL, 0 };
 int mac_priority[16] = { GNUTLS_MAC_SHA, GNUTLS_MAC_MD5, 0 };
@@ -235,7 +235,6 @@ int main(int argc, char **argv)
       /* allow the use of private ciphersuites.
        */
       gnutls_handshake_set_private_extensions( state, 1);
-      gnutls_handshake_set_exportable_detection( state, 1);
 
       if (i == 1) {
 	 gnutls_session_set_data(state, session, session_size);
@@ -249,7 +248,7 @@ int main(int argc, char **argv)
       gnutls_mac_set_priority(state, mac_priority);
       gnutls_cert_type_set_priority(state, cert_type_priority);
 
-      gnutls_dh_set_prime_bits(state, 1024);
+      gnutls_dh_set_prime_bits(state, 512);
 
       gnutls_cred_set(state, GNUTLS_CRD_ANON, anon_cred);
       if (srp_username!=NULL)
@@ -557,8 +556,10 @@ void gaa_parser(int argc, char **argv)
 	    cipher_priority[j++] = GNUTLS_CIPHER_TWOFISH_128_CBC;
 	 if (strncasecmp(info.ciphers[i], "3DE", 3) == 0)
 	    cipher_priority[j++] = GNUTLS_CIPHER_3DES_CBC;
-	 if (strncasecmp(info.ciphers[i], "ARC", 3) == 0)
-	    cipher_priority[j++] = GNUTLS_CIPHER_ARCFOUR;
+	 if (strcasecmp(info.ciphers[i], "ARCFOUR-40") == 0)
+	    cipher_priority[j++] = GNUTLS_CIPHER_ARCFOUR_40;
+	 if (strcasecmp(info.ciphers[i], "ARCFOUR") == 0)
+	    cipher_priority[j++] = GNUTLS_CIPHER_ARCFOUR_128;
 	 if (strncasecmp(info.ciphers[i], "NUL", 3) == 0)
 	    cipher_priority[j++] = GNUTLS_CIPHER_NULL;
       }
@@ -589,11 +590,13 @@ void gaa_parser(int argc, char **argv)
       for (j = i = 0; i < info.nkx; i++) {
 	 if (strncasecmp(info.kx[i], "SRP", 3) == 0)
 	    kx_priority[j++] = GNUTLS_KX_SRP;
-	 if (strncasecmp(info.kx[i], "RSA", 3) == 0)
+	 if (strcasecmp(info.kx[i], "RSA") == 0)
 	    kx_priority[j++] = GNUTLS_KX_RSA;
-	 if (strncasecmp(info.kx[i], "DHE_RSA", 7) == 0)
+	 if (strcasecmp(info.kx[i], "RSA-EXPORT") == 0)
+	    kx_priority[j++] = GNUTLS_KX_RSA_EXPORT;
+	 if (strncasecmp(info.kx[i], "DHE-RSA", 7) == 0)
 	    kx_priority[j++] = GNUTLS_KX_DHE_RSA;
-	 if (strncasecmp(info.kx[i], "DHE_DSS", 7) == 0)
+	 if (strncasecmp(info.kx[i], "DHE-DSS", 7) == 0)
 	    kx_priority[j++] = GNUTLS_KX_DHE_DSS;
 	 if (strncasecmp(info.kx[i], "ANON", 4) == 0)
 	    kx_priority[j++] = GNUTLS_KX_ANON_DH;
