@@ -94,7 +94,7 @@ char *x509_crlfile = NULL;
 		"\n" \
 		"<HTML><BODY>\n" \
 		"<CENTER><H1>This is <a href=\"http://www.gnu.org/software/gnutls\">" \
-		"GNUTLS</a></H1>\n\n"
+		"GNUTLS</a></H1></CENTER>\n\n"
 
 #define RENEGOTIATE
 
@@ -153,6 +153,7 @@ static void listener_free (listener_item * j)
 static int prime_nums[] = { 768, 1024, 0 };
 
 GNUTLS_DH_PARAMS dh_params;
+GNUTLS_RSA_PARAMS rsa_params;
 
 static int generate_dh_primes(void)
 {
@@ -171,7 +172,7 @@ static int generate_dh_primes(void)
        * security requirements.
        */
       printf
-	  ("Generating Diffie Hellman parameters [%d]. Please wait...",
+	  ("Generating Diffie Hellman parameters [%d]. Please wait...\n",
 	   prime_nums[i]);
       fflush(stdout);
 
@@ -193,15 +194,54 @@ static int generate_dh_primes(void)
    return 0;
 }
 
+static int generate_rsa_params(void)
+{
+   gnutls_datum m, e, d, p, q, u;
+
+   if (gnutls_rsa_params_init(&rsa_params) < 0) {
+      fprintf(stderr, "Error in rsa parameter initialization\n");
+      exit(1);
+   }
+
+   /* Generate RSA parameters - for use with RSA-export
+    * cipher suites. These should be discarded and regenerated
+    * once a day, once every 500 transactions etc. Depends on the
+    * security requirements.
+    */
+   printf
+	  ("Generating temporary RSA parameters. Please wait...\n");
+   fflush(stdout);
+
+   if (gnutls_rsa_params_generate(&m, &e, &d, &p, &q, &u, 512) < 0) {
+	 fprintf(stderr, "Error in rsa parameter generation\n");
+	 exit(1);
+   }
+
+   if (gnutls_rsa_params_set
+	  (rsa_params, m, e, d, p, q, u, 512) < 0) {
+	 fprintf(stderr, "Error in rsa parameter setting\n");
+	 exit(1);
+   }
+
+   free(m.data);
+   free(e.data);
+   free(d.data);
+   free(p.data);
+   free(q.data);
+   free(u.data);
+
+   return 0;
+}
+
 int protocol_priority[16] = { GNUTLS_TLS1, GNUTLS_SSL3, 0 };
 int kx_priority[16] =
     { GNUTLS_KX_DHE_DSS, GNUTLS_KX_RSA, GNUTLS_KX_DHE_RSA, GNUTLS_KX_SRP,
   /* Do not use anonymous authentication, unless you know what that means */ 
-  GNUTLS_KX_ANON_DH, 0
+  GNUTLS_KX_ANON_DH, GNUTLS_KX_RSA_EXPORT, 0
 };
 int cipher_priority[16] =
     { GNUTLS_CIPHER_RIJNDAEL_128_CBC, GNUTLS_CIPHER_3DES_CBC,
-   GNUTLS_CIPHER_ARCFOUR, 0
+   GNUTLS_CIPHER_ARCFOUR_128, GNUTLS_CIPHER_ARCFOUR_40, 0
 };
 
 int comp_priority[16] = { GNUTLS_COMP_ZLIB, GNUTLS_COMP_NULL, 0 };
@@ -252,12 +292,12 @@ static char DEFAULT_DATA[] = "This is the default message reported "
 /* Creates html with the current state information.
  */
 #define tmp2 &http_buffer[strlen(http_buffer)]
-char* peer_print_info(GNUTLS_STATE state, int *ret_length)
+char* peer_print_info(GNUTLS_STATE state, int *ret_length, const char* header)
 {
    const char *tmp;
    unsigned char sesid[32];
    int sesid_size, i;
-   char* http_buffer = malloc(5*1024);
+   char* http_buffer = malloc(5*1024 + strlen(header));
 
    if (http_buffer==NULL) return NULL;
    if (quiet != 0) {
@@ -296,20 +336,6 @@ char* peer_print_info(GNUTLS_STATE state, int *ret_length)
 	      gnutls_dh_get_prime_bits(state));
    }
 
-   /* print state information */
-   strcat(http_buffer, "<P>\n");
-
-   tmp = gnutls_protocol_get_name(gnutls_protocol_get_version(state));
-   sprintf(tmp2, "Protocol version: <b>%s</b><br>\n", tmp);
-
-   if (gnutls_auth_get_type(state) == GNUTLS_CRD_CERTIFICATE) {
-      tmp = gnutls_cert_type_get_name(gnutls_cert_type_get(state));
-      sprintf(tmp2, "Certificate Type: <b>%s</b><br>\n", tmp);
-   }
-
-   tmp = gnutls_kx_get_name(gnutls_kx_get(state));
-   sprintf(tmp2, "Key Exchange: <b>%s</b><br>\n", tmp);
-
    if (gnutls_kx_get(state) == GNUTLS_KX_DHE_RSA
        || gnutls_kx_get(state) == GNUTLS_KX_DHE_DSS) {
       sprintf(tmp2,
@@ -317,14 +343,36 @@ char* peer_print_info(GNUTLS_STATE state, int *ret_length)
 	      gnutls_dh_get_prime_bits(state));
    }
 
+   /* print state information */
+   strcat(http_buffer, "<P>\n");
+
+   tmp = gnutls_protocol_get_name(gnutls_protocol_get_version(state));
+   sprintf(tmp2, "<TABLE border=1><TR><TD>Protocol version:</TD><TD>%s</TD></TR>\n", tmp);
+
+   if (gnutls_auth_get_type(state) == GNUTLS_CRD_CERTIFICATE) {
+      tmp = gnutls_cert_type_get_name(gnutls_cert_type_get(state));
+      sprintf(tmp2, "<TR><TD>Certificate Type:</TD><TD>%s</TD></TR>\n", tmp);
+   }
+
+   tmp = gnutls_kx_get_name(gnutls_kx_get(state));
+   sprintf(tmp2, "<TR><TD>Key Exchange:</TD><TD>%s</TD></TR>\n", tmp);
+
    tmp = gnutls_compression_get_name(gnutls_compression_get(state));
-   sprintf(tmp2, "Compression: <b>%s</b><br>\n", tmp);
+   sprintf(tmp2, "<TR><TD>Compression</TD><TD>%s</TD></TR>\n", tmp);
 
    tmp = gnutls_cipher_get_name(gnutls_cipher_get(state));
-   sprintf(tmp2, "Cipher: <b>%s</b><br>\n", tmp);
+   sprintf(tmp2, "<TR><TD>Cipher</TD><TD>%s</TD></TR>\n", tmp);
 
    tmp = gnutls_mac_get_name(gnutls_mac_get(state));
-   sprintf(tmp2, "MAC: <b>%s</b><br>\n", tmp);
+   sprintf(tmp2, "<TR><TD>MAC</TD><TD>%s</TD></TR>\n", tmp);
+
+   tmp = gnutls_cipher_suite_get_name( gnutls_kx_get(state),
+   	gnutls_cipher_get(state), gnutls_mac_get(state));
+   sprintf(tmp2, "<TR><TD>Ciphersuite</TD><TD>%s</TD></TR></p></TABLE>\n", tmp);
+
+   strcat( http_buffer, "<hr><P>Your header was:<PRE>");
+   strcat( http_buffer, header);
+   strcat( http_buffer, "</PRE></P>");
 
    strcat(http_buffer, "</P>\n"HTTP_END);
 
@@ -386,7 +434,7 @@ static void get_response(GNUTLS_STATE state, char *request, char **response, int
     
 //    *response = peer_print_info(state, request+4, h, response_length);
     if (http!=0) {
-	*response = peer_print_info(state, response_length);
+	*response = peer_print_info(state, response_length, h);
     } else {
     	*response = strdup( request);
     	*response_length = strlen( *response);
@@ -463,8 +511,10 @@ int main(int argc, char **argv)
     * Diffie Hellman. See gnutls_dh_params_generate(), and
     * gnutls_dh_params_set().
     */
-   if (generate != 0)
+   if (generate != 0) {
+      generate_rsa_params();
       generate_dh_primes();
+   }
 
    if (gnutls_certificate_allocate_cred(&cert_cred) < 0) {
       fprintf(stderr, "memory error\n");
@@ -515,11 +565,16 @@ int main(int argc, char **argv)
 	 exit(1);
       }
 
-   if (generate != 0)
+   if (generate != 0) {
       if (gnutls_certificate_set_dh_params(cert_cred, dh_params) < 0) {
 	 fprintf(stderr, "Error while setting DH parameters\n");
 	 exit(1);
       }
+      if (gnutls_certificate_set_rsa_params(cert_cred, rsa_params) < 0) {
+	 fprintf(stderr, "Error while setting RSA parameters\n");
+	 exit(1);
+      }
+   }
 
    /* this is a password file (created with the included srpcrypt utility) 
     * Read README.crypt prior to using SRP.
@@ -899,7 +954,7 @@ void gaa_parser(int argc, char **argv)
 	 if (strncasecmp(info.ciphers[i], "3DE", 3) == 0)
 	    cipher_priority[j++] = GNUTLS_CIPHER_3DES_CBC;
 	 if (strncasecmp(info.ciphers[i], "ARC", 3) == 0)
-	    cipher_priority[j++] = GNUTLS_CIPHER_ARCFOUR;
+	    cipher_priority[j++] = GNUTLS_CIPHER_ARCFOUR_128;
 	 if (strncasecmp(info.ciphers[i], "NUL", 3) == 0)
 	    cipher_priority[j++] = GNUTLS_CIPHER_NULL;
       }
@@ -930,11 +985,13 @@ void gaa_parser(int argc, char **argv)
       for (j = i = 0; i < info.nkx; i++) {
 	 if (strncasecmp(info.kx[i], "SRP", 3) == 0)
 	    kx_priority[j++] = GNUTLS_KX_SRP;
-	 if (strncasecmp(info.kx[i], "RSA", 3) == 0)
+	 if (strcasecmp(info.kx[i], "RSA") == 0)
 	    kx_priority[j++] = GNUTLS_KX_RSA;
-	 if (strncasecmp(info.kx[i], "DHE_RSA", 7) == 0)
+	 if (strcasecmp(info.kx[i], "RSA-EXPORT") == 0)
+	    kx_priority[j++] = GNUTLS_KX_RSA_EXPORT;
+	 if (strncasecmp(info.kx[i], "DHE-RSA", 7) == 0)
 	    kx_priority[j++] = GNUTLS_KX_DHE_RSA;
-	 if (strncasecmp(info.kx[i], "DHE_DSS", 7) == 0)
+	 if (strncasecmp(info.kx[i], "DHE-DSS", 7) == 0)
 	    kx_priority[j++] = GNUTLS_KX_DHE_DSS;
 	 if (strncasecmp(info.kx[i], "ANON", 4) == 0)
 	    kx_priority[j++] = GNUTLS_KX_ANON_DH;
